<?php

namespace App\Controller;

use App\Entity\ExperienceProfessionnelle;
use App\Form\ExperienceProfessionnelleType;
use App\Repository\ExperienceProfessionnelleRepository;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

/**
 * @Route("/experience/professionnelle")
 */
class ExperienceProfessionnelleController extends AbstractController
{
    /**
     * @Route("/", name="experience_professionnelle_index", methods={"GET"})
     */
    public function index(ExperienceProfessionnelleRepository $experienceProfessionnelleRepository): Response
    {
        return $this->render('experience_professionnelle/index.html.twig', [
            'experience_professionnelles' => $experienceProfessionnelleRepository->findAll(),
        ]);
    }

    /**
     * @Route("/new", name="experience_professionnelle_new", methods={"GET","POST"})
     */
    public function new(Request $request): Response
    {
        $experienceProfessionnelle = new ExperienceProfessionnelle();
        $form = $this->createForm(ExperienceProfessionnelleType::class, $experienceProfessionnelle);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->persist($experienceProfessionnelle);
            $entityManager->flush();

            return $this->redirectToRoute('experience_professionnelle_index');
        }

        return $this->render('experience_professionnelle/new.html.twig', [
            'experience_professionnelle' => $experienceProfessionnelle,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="experience_professionnelle_show", methods={"GET"})
     */
    public function show(ExperienceProfessionnelle $experienceProfessionnelle): Response
    {
        return $this->render('experience_professionnelle/show.html.twig', [
            'experience_professionnelle' => $experienceProfessionnelle,
        ]);
    }

    /**
     * @Route("/{id}/edit", name="experience_professionnelle_edit", methods={"GET","POST"})
     */
    public function edit(Request $request, ExperienceProfessionnelle $experienceProfessionnelle): Response
    {
        $form = $this->createForm(ExperienceProfessionnelleType::class, $experienceProfessionnelle);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $this->getDoctrine()->getManager()->flush();

            return $this->redirectToRoute('experience_professionnelle_index');
        }

        return $this->render('experience_professionnelle/edit.html.twig', [
            'experience_professionnelle' => $experienceProfessionnelle,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{id}", name="experience_professionnelle_delete", methods={"DELETE"})
     */
    public function delete(Request $request, ExperienceProfessionnelle $experienceProfessionnelle): Response
    {
        if ($this->isCsrfTokenValid('delete'.$experienceProfessionnelle->getId(), $request->request->get('_token'))) {
            $entityManager = $this->getDoctrine()->getManager();
            $entityManager->remove($experienceProfessionnelle);
            $entityManager->flush();
        }

        return $this->redirectToRoute('experience_professionnelle_index');
    }
}
