<?php

namespace App\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\Request;
use App\Entity\Individu;
use App\Entity\ExperienceProfessionnelle;

class TemplateController extends AbstractController
{
    /**
     * @Route("/template", name="template")
     */
    public function index()
    {
        return $this->render('template/index.html.twig', [
            'controller_name' => 'TemplateController',
        ]);
    }

    
    /**
    *@Route("/page1/{nom}", name="page1",methods={"GET"})
    */
    public function maPage1(Request $request, $nom = "Moussa"){
    	return $this->render('page1/index.html.twig', array('maVar' => $nom));
    }
    
    /**
    *@Route("/accueil/{nom}", name="accueil",methods={"GET"})
    */
    public function accueilPage(Request $request, $nom = "Moussa"){
    	return $this->render('page1/accueil.html.twig', array('monNom' => $nom, "message"=>"Accueil"));
    }
    
    
    /**
    *@Route("/contact", name="contact")
    */
    public function contact($nom="INSSA", $prenom="Moussa"){
    	return $this->render('page1/contact.html.twig', array('nom' => $nom,'prenom'=>$prenom));
    }
    
    /**
     * @Route("/ajoutIndividu/{nom}-{prenom}", name="ajoutIndividu")
     */
    public function ajoutIndividu($nom="INSSA", $prenom="Moussa")
    {
        $ind = new Individu();
        $ind->setNom($nom);
        $ind->setPrenom($prenom);
        $ind->setDateNaissance(new \DateTime());
        $ind->setAfficherDateNaissance(true);
        $em = $this->getDoctrine()->getManager();
        $em->persist($ind);
        $em->flush();

        return $this->render('page1/ajoutIndividuConfirmer.html.twig', 
            array(
                'message' => 'Individu '.$nom.' '.$prenom.' ajouté !'
            )
        );
    }

    /**
    *
    * @Route("/listeIndividus", name="listeIndividus")
    */
    public function listeIndividus()
    {
        
        $listIndividus = $this->getDoctrine()->getManager()->getRepository(Individu::class)->findAll();

        return $this->render('page1/listeIndividus.html.twig',
                array(
                    "message" => "Liste des individus",
                    "listIndividus" => $listIndividus
                ));
    }
    
    /**
    * @Route("/exp/{id}", name="exp")
    */
    public function listeExp($id)
    {
        $em = $this->getDoctrine()->getManager();
        $er = $em->getRepository(Individu::class);
        $individu = $er->find($id);
        $experiences = $em->getRepository(ExperienceProfessionnelle::class)->findBy(['individu'=> $id],['dateDebut'=> 'DESC']);
        return $this->render('page1/expbyindividu.html.twig', [
            'ind'=>$individu,
            'exp_pro'=>$experiences
        ]);
    }
    
    
    
    /** 
    *
    * @Route("/delete/{id}",name="delete")
    */
    public function deleteAction($id)
    {
        $em = $this->getDoctrine()->getManager();
        $obj = $em->getRepository(Individu::class)->find($id);
        $em->remove($obj);
        $em->flush();
        return $this->redirectToRoute('listeIndividus');
    }

    /** 
    *
    * @Route("/supprimer/{id}",name="supprimer")
    */
    public function supprimerAction($id) {

        $em = $this->getDoctrine()->getManager();
        $lindividu = $em->getRepository(Individu::class)->find($id);
        if (!$lindividu) {
          throw $this->createNotFoundException(
                  'Aucun matériel trouvé pour l\'id ' . $id
          );
        }
        $em->flush();
        return $this->redirectToRoute('suppressionOKYoupi', 
            array("id"=>$lindividu->getId()));
    }
    
    
    /**
    * @Route("/suppressionOK/{id}", name="suppressionOKYoupi")
    */
    public function suppressionOKYoupi($id)
    {
        // Sans précaution sur l'existence : 
        $individu = $this->getDoctrine()->getRepository(Individu::class)->find($id);

        return $this->render('page1/suppressionIndividuConfirmation.html.twig',
                array(
                    "message" => "Suppression Individu",
                    "individu" => $individu 
                )
            );
    }



}

