<?php

namespace App\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;

/**
 * @ORM\Entity(repositoryClass="App\Repository\IndividuRepository")
 */
class Individu
{

    
    /**
     * @ORM\Id()
     * @ORM\GeneratedValue()
     * @ORM\Column(type="integer")
     */
    private $id;

    /**
     * @ORM\Column(type="string", length=255)
     */
    private $nom;

    /**
     * @ORM\Column(type="string", length=255)
     */
    private $prenom;

    /**
     * @ORM\Column(type="date", nullable=true)
     */
    private $dateNaissance;

    /**
     * @ORM\Column(type="boolean")
     */
    private $afficherDateNaissance;

    /**
     * @ORM\ManyToMany(targetEntity="App\Entity\Competence", inversedBy="individus")
     */
    private $competences;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\ExperienceProfessionnelle", mappedBy="individu", cascade={"remove"})
     */
    private $experienceProfessionnelles;

    public function __construct()
    {
        $this->competences = new ArrayCollection();
        $this->experienceProfessionnelles = new ArrayCollection();
    }
    
    
    public function getId(): ?int
    {
        return $this->id;
    }

    public function getNom(): ?string
    {
        return $this->nom;
    }

    public function setNom(string $nom): self
    {
        $this->nom = $nom;

        return $this;
    }

    public function getPrenom(): ?string
    {
        return $this->prenom;
    }

    public function setPrenom(string $prenom): self
    {
        $this->prenom = $prenom;

        return $this;
    }

    public function getDateNaissance(): ?\DateTimeInterface
    {
        return $this->dateNaissance;
    }

    public function setDateNaissance(?\DateTimeInterface $dateNaissance): self
    {
        $this->dateNaissance = $dateNaissance;

        return $this;
    }

    public function getAfficherDateNaissance(): ?bool
    {
        return $this->afficherDateNaissance;
    }

    public function setAfficherDateNaissance(bool $afficherDateNaissance): self
    {
        $this->afficherDateNaissance = $afficherDateNaissance;

        return $this;
    }

    /**
     * @return Collection|Competence[]
     */
    public function getCompetences(): Collection
    {
        return $this->competences;
    }

    public function addCompetence(Competence $competence): self
    {
        if (!$this->competences->contains($competence)) {
            $this->competences[] = $competence;
        }

        return $this;
    }

    public function removeCompetence(Competence $competence): self
    {
        if ($this->competences->contains($competence)) {
            $this->competences->removeElement($competence);
        }

        return $this;
    }

    /**
     * @return Collection|ExperienceProfessionnelle[]
     */
    public function getExperienceProfessionnelles(): Collection
    {
        return $this->experienceProfessionnelles;
    }

    public function addExperienceProfessionnelle(ExperienceProfessionnelle $experienceProfessionnelle): self
    {
        if (!$this->experienceProfessionnelles->contains($experienceProfessionnelle)) {
            $this->experienceProfessionnelles[] = $experienceProfessionnelle;
            $experienceProfessionnelle->setIndividu($this);
        }

        return $this;
    }

    public function removeExperienceProfessionnelle(ExperienceProfessionnelle $experienceProfessionnelle): self
    {
        if ($this->experienceProfessionnelles->contains($experienceProfessionnelle)) {
            $this->experienceProfessionnelles->removeElement($experienceProfessionnelle);
            // set the owning side to null (unless already changed)
            if ($experienceProfessionnelle->getIndividu() === $this) {
                $experienceProfessionnelle->setIndividu(null);
            }
        }

        return $this;
    }
}
